@@ -22,6 +22,8 @@ class NeedtableDirective(FilterBase):
     Directive present filtered needs inside a table.
     """
 
+    optional_arguments = 1
+    final_argument_whitespace = True
     option_spec = {
         "show_filters": directives.flag,
         "show_parts": directives.flag,
@@ -62,11 +64,16 @@ class NeedtableDirective(FilterBase):
 
         sort = self.options.get("sort", "id_complete")
 
+        title = None
+        if self.arguments:
+            title = self.arguments[0]
+
         # Add the need and all needed information
         env.need_all_needtables[targetid] = {
             "docname": env.docname,
             "lineno": self.lineno,
             "target_node": targetnode,
+            "caption": title,
             "columns": columns,
             "style": style,
             "style_row": style_row,
@@ -86,7 +93,7 @@ class NeedtableDirective(FilterBase):
 @profile("NEEDTABLE")
 def process_needtables(app, doctree, fromdocname):
     """
-    Replace all needtables nodes with a tale of filtered noded.
+    Replace all needtables nodes with a table of filtered nodes.
 
     :param app:
     :param doctree:
@@ -113,6 +120,7 @@ def process_needtables(app, doctree, fromdocname):
         if not app.config.needs_include_needs:
             # Ok, this is really dirty.
             # If we replace a node, docutils checks, if it will not lose any attributes.
+            # If we replace a node, docutils checks, if it will not lose any attributes.
             # But this is here the case, because we are using the attribute "ids" of a node.
             # However, I do not understand, why losing an attribute is such a big deal, so we delete everything
             # before docutils claims about it.
@@ -135,6 +143,13 @@ def process_needtables(app, doctree, fromdocname):
 
         # Prepare table
         classes = ["NEEDS_{style}".format(style=style)]
+
+        # Only add the theme specific "do not touch this table" class, if we use a style which
+        # care about table layout and styling. The normal "TABLE" style is using the Sphinx default table
+        # css classes and therefore must be handled by the themes.
+        if style != "TABLE":
+            classes.extend(app.config.needs_table_classes)
+
         content = nodes.table(classes=classes)
         tgroup = nodes.tgroup()
 
@@ -159,7 +174,7 @@ def process_needtables(app, doctree, fromdocname):
         all_needs = list(all_needs.values())
 
         # Perform filtering of needs
-        found_needs = process_filters(all_needs, current_needtable)
+        found_needs = process_filters(app, all_needs, current_needtable)
 
         def get_sorter(key):
             """
@@ -231,19 +246,24 @@ def process_needtables(app, doctree, fromdocname):
             # Need part rows
             if current_needtable["show_parts"] and need_info["is_need"]:
                 for part in need_info["parts"].values():
-                    row = nodes.row(classes=["need_part"])
-                    temp_part = part.copy()  # The dict needs to be manipulated, so that row_col_maker() can be used
+                    # update the part with all information from its parent
+                    # this is required to make ID links work
+                    temp_part = part.copy()  # The dict has to be manipulated, so that row_col_maker() can be used
+                    temp_part = {**need_info, **temp_part}
+                    temp_part["id_complete"] = f"{need_info['id']}.{temp_part['id']}"
+                    temp_part["id_parent"] = need_info["id"]
                     temp_part["docname"] = need_info["docname"]
 
+                    row = nodes.row(classes=["need_part"])
+
                     for option, title in current_needtable["columns"]:
                         if option == "ID":
-                            temp_part["id"] = ".".join([need_info["id"], part["id"]])
                             row += row_col_maker(
                                 app,
                                 fromdocname,
                                 env.needs_all_needs,
                                 temp_part,
-                                "id",
+                                "id_complete",
                                 make_ref=True,
                                 prefix=app.config.needs_part_prefix,
                             )
@@ -257,10 +277,10 @@ def process_needtables(app, doctree, fromdocname):
                                 prefix=app.config.needs_part_prefix,
                             )
                         elif option in link_type_list.keys() and (
-                            option == link_type_list[option]["option"].upper() + "_BACK"
+                            option == "INCOMING"
+                            or option == link_type_list[option]["option"].upper() + "_BACK"
                             or option == link_type_list[option]["incoming"].upper()
                         ):
-
                             row += row_col_maker(
                                 app,
                                 fromdocname,
@@ -281,4 +301,9 @@ def process_needtables(app, doctree, fromdocname):
         if current_needtable["show_filters"]:
             content.append(used_filter_paragraph(current_needtable))
 
+        if current_needtable["caption"]:
+            title_text = current_needtable["caption"]
+            title = nodes.title(title_text, "", nodes.Text(title_text))
+            content.insert(0, title)
+
         node.replace_self(content)
