@@ -95,7 +95,7 @@ from sphinxcontrib.needs.services.manager import ServiceManager
 from sphinxcontrib.needs.utils import INTERNALS, NEEDS_FUNCTIONS
 from sphinxcontrib.needs.warnings import process_warnings
 
-VERSION = "0.7.2"
+VERSION = "0.7.3"
 NEEDS_FUNCTIONS.clear()
 
 
@@ -140,7 +140,7 @@ def setup(app):
     )
     app.add_config_value("needs_show_link_type", False, "html", types=[bool])
     app.add_config_value("needs_show_link_title", False, "html", types=[bool])
-    app.add_config_value("needs_file", "needs.json", "html")
+    app.add_config_value("needs_file", None, "html")
     app.add_config_value("needs_table_columns", "ID;TITLE;STATUS;TYPE;OUTGOING;TAGS", "html")
     app.add_config_value("needs_table_style", "DATATABLES", "html")
 
