@@ -40,6 +40,12 @@ def process_warnings(app, exception):
 
     needs = env.needs_all_needs
 
+    # Exclude external needs for warnings check
+    checked_needs = {}
+    for need_id, need in needs.items():
+        if not need["is_external"]:
+            checked_needs[need_id] = need
+
     # warnings = app.config.needs_warnings
     warnings = NEEDS_CONFIG.get("warnings")
 
@@ -51,11 +57,11 @@ def process_warnings(app, exception):
         for warning_name, warning_filter in warnings.items():
             if isinstance(warning_filter, str):
                 # filter string used
-                result = filter_needs(app, needs.values(), warning_filter)
+                result = filter_needs(app, checked_needs.values(), warning_filter)
             elif hasattr(warning_filter, "__call__"):
                 # custom defined filter code used from conf.py
                 result = []
-                for need in needs.values():
+                for need in checked_needs.values():
                     if warning_filter(need, logger):
                         result.append(need)
             else:
@@ -66,6 +72,16 @@ def process_warnings(app, exception):
             else:
                 need_ids = [x["id"] for x in result]
 
+                # Set Sphinx statuscode to 1, only if -W is used with sphinx-build
+                # Because Sphinx statuscode got calculated in very early build phase and based on warning_count
+                # Sphinx-needs warnings check hasn't happened yet
+                # see deatils in https://github.com/sphinx-doc/sphinx/blob/81a4fd973d4cfcb25d01a7b0be62cdb28f82406d/sphinx/application.py#L345 # noqa
+                # To be clear, app.keep_going = -W and --keep-going, and will overrite -W after
+                # see details in https://github.com/sphinx-doc/sphinx/blob/4.x/sphinx/application.py#L182
+                if app.statuscode == 0:
+                    if app.keep_going or app.warningiserror:
+                        app.statuscode = 1
+
                 # get the text for used filter, either from filter string or function name
                 if hasattr(warning_filter, "__call__"):
                     warning_text = getattr(warning_filter, "__name__")
